@@ -2,27 +2,51 @@
 # Copyright (c) Max-Planck-Institut für Eisenforschung GmbH - Computational Materials Design (CM) Department
 # Distributed under the terms of "New BSD License", see the LICENSE file.
 
+import random
+import warnings
+import itertools
 from multiprocessing import cpu_count
 from pyiron_atomistics.atomistics.job.atomistic import AtomisticGenericJob
 from pyiron_base import state, DataContainer, GenericParameters, ImportAlarm
+from pyiron_atomistics.atomistics.structure.periodic_table import ChemicalElement
 from pyiron_atomistics.atomistics.structure.atoms import (
     Atoms,
     ase_to_pyiron,
     pyiron_to_ase,
 )
-from pymatgen.io.ase import AseAtomsAdaptor
 import numpy as np
 
 try:
     from sqsgenerator.core.sqs import ParallelSqsIterator
 
+    import_alarm = ImportAlarm(
+        "SQSJob relies on the [sqsgenerator module](https://github.com/dgehringer/sqsgenerator) module. The package "
+        "got a major update (0.0.5 -> 0.1) recently. Please consider to update the package, e. g. with "
+        "`conda update -c conda-forge sqsgenerator`"
+    )
+    DEPRECATED_SQS_API = True
+except ImportError:
+    DEPRECATED_SQS_API = None
+
+try:
+    from sqsgenerator.settings import BadSettings
+    from sqsgenerator import sqs_optimize, process_settings, IterationMode
+
+    DEPRECATED_SQS_API = False
     import_alarm = ImportAlarm()
 except ImportError:
     import_alarm = ImportAlarm(
-        "SQSJob relies on sqsgenerator.core.sqs.ParallelSqsIterator, but this is unavailable. Please ensure your "
+        "SQSJob relies on the sqsgenerator module, but this is unavailable. Please ensure your "
         "python environment contains the [sqsgenerator module](https://github.com/dgehringer/sqsgenerator), e.g. with "
         "`conda install -c conda-forge sqsgenerator`."
     )
+    DEPRECATED_SQS_API = DEPRECATED_SQS_API or None
+
+
+from typing import Dict, Optional, Union, Iterable
+
+if DEPRECATED_SQS_API:
+    from pymatgen.io.ase import AseAtomsAdaptor
 
 __author__ = "Jan Janssen"
 __copyright__ = (
@@ -36,36 +60,192 @@ __status__ = "development"
 __date__ = "Aug 14, 2020"
 
 
-def pyiron_to_pymatgen(structure):
-    return AseAtomsAdaptor.get_structure(pyiron_to_ase(structure))
+def chemical_formula(atoms: Atoms) -> str:
+    def group_symbols():
+        for species, same in itertools.groupby(atoms.get_chemical_symbols()):
+            num_same = len(list(same))
+            yield species if num_same == 1 else f"{species}{num_same}"
+
+    return "".join(group_symbols())
 
 
-def pymatgen_to_pyiron(structure):
-    return ase_to_pyiron(AseAtomsAdaptor.get_atoms(structure))
+def map_dict(f, d: Dict) -> Dict:
+    return {k: f(v) for k, v in d.items()}
 
 
-def get_sqs_structures(
-    structure,
-    mole_fractions,
-    weights=None,
-    objective=0.0,
-    iterations=1e6,
-    output_structures=10,
-    num_threads=None,
-):
-    structure = pyiron_to_pymatgen(structure)
-    if not weights:
-        weights = {i: 1.0 / i for i in range(1, 7)}
-    if not num_threads:
-        # Thats default behaviour
-        num_threads = cpu_count()
-    iterator = ParallelSqsIterator(
-        structure, mole_fractions, weights, num_threads=num_threads
-    )
-    structures, decmp, iter_, cycle_time = iterator.iteration(
-        iterations=iterations, output_structures=output_structures, objective=objective
-    )
-    return [pymatgen_to_pyiron(s) for s in structures], decmp, iter_, cycle_time
+def mole_fractions_to_composition(
+    mole_fractions: Dict[str, float], num_atoms: int
+) -> Dict[str, int]:
+    # if the sum of x is less than 1 - 1/n then we are missing at least one atoms
+    if not (1.0 - 1 / num_atoms) < sum(mole_fractions.values()) < (1.0 + 1 / num_atoms):
+        raise ValueError(
+            "mole-fractions must sum up to one: {}".format(sum(mole_fractions.values()))
+        )
+
+    composition = map_dict(lambda x: x * num_atoms, mole_fractions)
+    # check to avoid partial occupation -> x_i * num_atoms is not an integer number
+    if any(
+        map(
+            lambda occupation: not float.is_integer(round(occupation, 1)),
+            composition.values(),
+        )
+    ):
+        # at least one of the specified species exhibits fractional occupation, we try to fix it by rounding
+        composition_ = map_dict(lambda occ: int(round(occ)), composition)
+        warnings.warn(
+            "The current mole-fraction specification cannot be applied to {} atoms, "
+            "as it would lead to fractional occupation. Hence, I have changed it from "
+            '"{}" -> "{}"'.format(
+                num_atoms,
+                mole_fractions,
+                map_dict(lambda n: n / num_atoms, composition_),
+            )
+        )
+        composition = composition_
+
+    # due to rounding errors there might be a difference of one atom
+    actual_atoms = sum(composition.values())
+    diff = actual_atoms - num_atoms
+    if abs(diff) == 1:
+        # it is not possible to distribute atoms equally e.g x_a = x_b = x_c = 1/3 on 32 atoms
+        # we remove one randomly bet we inform the user
+        removed_species = random.choice(tuple(composition))
+        composition[removed_species] -= 1
+        warnings.warn(
+            'It is not possible to distribute the species properly. Therefore one "{}" atom was removed. '
+            "This changes the input mole-fraction specification. "
+            '"{}" -> "{}"'.format(
+                removed_species,
+                mole_fractions,
+                map_dict(lambda n: n / num_atoms, composition),
+            )
+        )
+    elif abs(diff) > 1:
+        # something else is wrong with the mole-fractions input
+        raise ValueError(
+            "Cannot interpret mole-fraction dict {}".format(mole_fractions)
+        )
+
+    return composition
+
+
+if DEPRECATED_SQS_API:
+
+    def pyiron_to_pymatgen(structure):
+        return AseAtomsAdaptor.get_structure(pyiron_to_ase(structure))
+
+    def pymatgen_to_pyiron(structure):
+        return ase_to_pyiron(AseAtomsAdaptor.get_atoms(structure))
+
+    def get_sqs_structures(
+        structure,
+        mole_fractions,
+        weights=None,
+        objective=0.0,
+        iterations=1e6,
+        output_structures=10,
+        num_threads=None,
+    ):
+        structure = pyiron_to_pymatgen(structure)
+        if not weights:
+            weights = {i: 1.0 / i for i in range(1, 7)}
+        if not num_threads:
+            # Thats default behaviour
+            num_threads = cpu_count()
+
+        # preprocess mole-fractions, to print warnings is necessary
+        num_atoms = len(structure)
+        composition = mole_fractions_to_composition(mole_fractions, num_atoms)
+        mole_fractions = map_dict(lambda n: n / num_atoms, composition)
+
+        iterator = ParallelSqsIterator(
+            structure, mole_fractions, weights, num_threads=num_threads
+        )
+        structures, decmp, iter_, cycle_time = iterator.iteration(
+            iterations=iterations,
+            output_structures=output_structures,
+            objective=objective,
+        )
+        return [pymatgen_to_pyiron(s) for s in structures], decmp, iter_, cycle_time
+
+else:
+
+    def remap_sro(species: Iterable[str], array: np.ndarray):
+        # remaps computed short-range order parameters to style of sqsgenerator=v0.0.5
+        species = tuple(
+            sorted(species, key=lambda abbr: ChemicalElement(abbr).atomic_number)
+        )
+        return {
+            "{}-{}".format(si, sj): array[:, i, j].tolist()
+            for (i, si), (j, sj) in itertools.product(
+                enumerate(species), enumerate(species)
+            )
+            if j >= i
+        }
+
+    def remap_sqs_results(result):
+        # makes new interface compatible with old one
+        pyiron_structure = ase_to_pyiron(result["structure"])
+        return pyiron_structure, remap_sro(
+            set(pyiron_structure.get_chemical_symbols()), result["parameters"]
+        )
+
+    def transpose(it):
+        return zip(*it)
+
+    def get_sqs_structures(
+        structure: Atoms,
+        mole_fractions: Dict[str, Union[float, int]],
+        weights: Optional[Dict[int, float]] = None,
+        objective: Union[float, np.ndarray] = 0.0,
+        iterations: Union[float, int] = 1e6,
+        output_structures: int = 10,
+        mode: str = "random",
+        num_threads: Optional[int] = None,
+        prefactors: Optional[Union[float, np.ndarray]] = None,
+        pair_weights: Optional[np.ndarray] = None,
+        rtol: Optional[float] = None,
+        atol: Optional[float] = None,
+        which: Optional[Iterable[int]] = None,
+        shell_distances: Optional[Iterable[int]] = None,
+        minimal: Optional[bool] = True,
+        similar: Optional[bool] = True,
+    ):
+
+        structure = pyiron_to_ase(structure)
+        composition = mole_fractions_to_composition(mole_fractions, len(structure))
+
+        settings = dict(
+            atol=atol,
+            rtol=rtol,
+            mode=mode,
+            which=which,
+            structure=structure,
+            prefactors=prefactors,
+            shell_weights=weights,
+            iterations=iterations,
+            composition=composition,
+            pair_weights=pair_weights,
+            target_objective=objective,
+            shell_distances=shell_distances,
+            threads_per_rank=num_threads or cpu_count(),
+            max_output_configurations=output_structures,
+        )
+        # not specifying a parameter in settings causes sqsgenerator to choose a "sensible" default,
+        # hence we remove all entries with a None value
+
+        results, timings = sqs_optimize(
+            {param: value for param, value in settings.items() if value is not None},
+            minimal=minimal,
+            similar=similar,
+            make_structures=True,
+            structure_format="ase",
+        )
+
+        structures, sro_breakdown = transpose(map(remap_sqs_results, results.values()))
+        num_iterations = iterations
+        cycle_time = np.average(list(map_dict(np.average, timings).values()))
+        return structures, sro_breakdown, num_iterations, cycle_time
 
 
 class SQSJob(AtomisticGenericJob):
@@ -188,10 +368,7 @@ class SQSJob(AtomisticGenericJob):
         return db_dict
 
     def list_structures(self):
-        if self.status.finished:
-            return self._lst_of_struct
-        else:
-            return []
+        return self._lst_of_struct if self.status.finished else []
 
     def _get_structure(self, frame=-1, wrap_atoms=True):
         return self.list_structures()[frame]
