@@ -147,11 +147,9 @@ def _fit_coeffs_with_energies(
     energy = np.tile(energy, len(rotations))
     volume = np.tile(volume, len(rotations))
     # Create symmetric tensor for elastic tensor
-    strain = 0.5 * np.einsum("ni,nj->nij", strain_voigt, strain_voigt)
-    # Set lower triangle to 0 (which is the same as the upper triangle)
-    strain = np.triu(strain).reshape(-1, 36)
+    strain = 0.5 * np.einsum("ni,nj->nij", *2 * [strain_voigt])
     # Remove lower triangle
-    strain = strain[:, np.sum(strain, axis=0) != 0]
+    strain = np.array([s[np.triu_indices(6)] for s in strain])
     if higher_strains is not None:
         strain = np.concatenate((strain, higher_strains), axis=-1)
     if fit_first_order:
@@ -160,9 +158,9 @@ def _fit_coeffs_with_energies(
     reg = LinearRegression().fit(strain, energy)
     score = reg.score(strain, energy)
     # Create base tensor for elastic tensor
-    coeff = np.triu(np.ones((6, 6))).flatten()
+    coeff = np.zeros((6, 6))
     # Multiply upper triangle with upper triangle coeffs (v.s.)
-    coeff[coeff != 0] *= reg.coef_[:21] * eV_div_A3_to_GPa
+    coeff[np.triu_indices(6)] = reg.coef_[:21] * eV_div_A3_to_GPa
     coeff = coeff.reshape(6, 6)
     coeff = 0.5 * (coeff + coeff.T)
     return coeff, score
@@ -512,6 +510,10 @@ class ElasticTensor(AtomisticParallelMaster):
             normalize=self.input["normalize_magnitude"],
         ).tolist()
 
+    def save(self):
+        self.validate_ready_to_run()
+        super().save()
+
     def validate_ready_to_run(self):
         super().validate_ready_to_run()
         if self.input["use_symmetry"] and len(self.input["rotations"]) == 0:
