@@ -1213,11 +1213,8 @@ class LammpsBase(AtomisticGenericJob):
         new_ham = super(LammpsBase, self).restart(job_name=job_name, job_type=job_type)
         if new_ham.__name__ == self.__name__:
             new_ham.potential = self.potential
-            if os.path.isfile(os.path.join(self.working_directory, "restart.out")):
-                new_ham.read_restart_file(filename="restart.out")
-                new_ham.restart_file_list.append(
-                    posixpath.join(self.working_directory, "restart.out")
-                )
+            new_ham.read_restart_file(filename="restart.out")
+            new_ham.restart_file_list.append(self.get_workdir_file("restart.out"))
         return new_ham
 
     def _get_lammps_structure(self, structure=None, cutoff_radius=None):
