@@ -235,8 +235,8 @@ class SphinxInteractive(SphinxBase, GenericInteractive):
         algorithm=None,
         retain_charge_density=False,
         retain_electrostatic_potential=False,
-        ionic_energy_tolerance=0.0,
-        ionic_force_tolerance=1.0e-2,
+        ionic_energy_tolerance=None,
+        ionic_force_tolerance=None,
         ionic_energy=None,
         ionic_forces=None,
         volume_only=False,
